"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.router = void 0;
/**
 *
 */
const http_status_codes_1 = require("http-status-codes");
const express_1 = require("express");
const middleware_1 = require("../middleware");
const hook_1 = require("../models/hook");
const enums_1 = require("../enums");
exports.router = (0, express_1.Router)();
/**
 * Get hook
 */
exports.router.get("/-/npm/v1/hooks/hook/:hookId", (0, middleware_1.asyncWrap)(async (req, res) => {
    res
        .status(http_status_codes_1.StatusCodes.OK)
        .json(await hook_1.Hook.getUserHooks(res.locals.user._id));
}));
/**
 * List Hooks
 *
 * package: filter by package name; regexp patterns are not parsed
 * limit: return at most N hooks
 * offset: start at the Nth hook (use with limit for pagination)
 */
exports.router.get("/-/npm/v1/hooks", (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageHooks), (0, middleware_1.asyncWrap)(async (req, res) => {
    res
        .status(http_status_codes_1.StatusCodes.OK)
        .json({ objects: await hook_1.Hook.getUserHooks(res.locals.user._id) });
}));
/**
 * Add Hook
 */
exports.router.post("/-/npm/v1/hooks/hook", (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageHooks), (0, express_1.json)(), (0, middleware_1.asyncWrap)(async (req, res) => {
    let { type, name, endpoint, secret } = req.body;
    if (type === "scope") {
        name = name.replace(new RegExp("^[@]+"), "");
    }
    const hook = await hook_1.Hook.create({
        type,
        name,
        endpoint,
        secret,
        ownerId: res.locals.user._id,
    });
    res.status(http_status_codes_1.StatusCodes.CREATED).json(hook);
}));
/**
 * Update Hooks
 */
exports.router.put("/-/npm/v1/hooks/hook/:hookId", (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageHooks), (0, express_1.json)(), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { endpoint, secret } = req.body;
    const update = await hook_1.Hook.update({ endpoint, secret }, {
        where: {
            id: req.params.hookId,
            ownerId: res.locals.user._id,
        },
    });
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
/**
 * Get Hooks
 */
exports.router.delete("/-/npm/v1/hooks/hook/:hookId", (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageHooks), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { hookId } = req.params;
    const result = await hook_1.Hook.destroy({
        where: { id: hookId, ownerId: res.locals.user._id },
    });
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
//# sourceMappingURL=hooks.js.map